==> zio-aws-accessanalyzer_2.13-5.17.130.2-sources.jar: zio/aws/accessanalyzer/model/CreateAnalyzerRequest.scala <==
package zio.aws.accessanalyzer.model
import zio.aws.accessanalyzer.model.primitives.Name
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateAnalyzerRequest(
    analyzerName: Name,
    archiveRules: Option[
      Iterable[zio.aws.accessanalyzer.model.InlineArchiveRule]
    ] = None,
    clientToken: Option[String] = None,
    tags: Option[Map[String, String]] = None,
    `type`: zio.aws.accessanalyzer.model.Type
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest = {
    import CreateAnalyzerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest
      .builder()
      .analyzerName(Name.unwrap(analyzerName): java.lang.String)
      .optionallyWith(
        archiveRules.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.archiveRules)
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .`type`(`type`.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.accessanalyzer.model.CreateAnalyzerRequest.ReadOnly =
    zio.aws.accessanalyzer.model.CreateAnalyzerRequest.wrap(buildAwsValue())
}
object CreateAnalyzerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.accessanalyzer.model.CreateAnalyzerRequest =
      zio.aws.accessanalyzer.model.CreateAnalyzerRequest(
        analyzerName,
        archiveRules.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        clientToken.map(value => value),
        tags.map(value => value),
        `type`
      )
    def analyzerName: Name
    def archiveRules
        : Option[List[zio.aws.accessanalyzer.model.InlineArchiveRule.ReadOnly]]
    def clientToken: Option[String]
    def tags: Option[Map[String, String]]
    def `type`: zio.aws.accessanalyzer.model.Type
    def getAnalyzerName: ZIO[Any, Nothing, Name] = ZIO.succeed(analyzerName)
    def getArchiveRules: ZIO[Any, AwsError, List[
      zio.aws.accessanalyzer.model.InlineArchiveRule.ReadOnly
    ]] = AwsError.unwrapOptionField("archiveRules", archiveRules)
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getTags: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("tags", tags)
    def getType: ZIO[Any, Nothing, zio.aws.accessanalyzer.model.Type] =
      ZIO.succeed(`type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest
  ) extends zio.aws.accessanalyzer.model.CreateAnalyzerRequest.ReadOnly {
    override val analyzerName: Name =
      zio.aws.accessanalyzer.model.primitives.Name(impl.analyzerName())
    override val archiveRules: Option[
      List[zio.aws.accessanalyzer.model.InlineArchiveRule.ReadOnly]
    ] = scala
      .Option(impl.archiveRules())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.accessanalyzer.model.InlineArchiveRule.wrap(item)
        }.toList
      )
    override val clientToken: Option[String] =
      scala.Option(impl.clientToken()).map(value => value: String)
    override val tags: Option[Map[String, String]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val `type`: zio.aws.accessanalyzer.model.Type =
      zio.aws.accessanalyzer.model.Type.wrap(impl.`type`())
  }
  def wrap(
      impl: software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest
  ): zio.aws.accessanalyzer.model.CreateAnalyzerRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-accessanalyzer_2.13-5.17.239.4-sources.jar: zio/aws/accessanalyzer/model/CreateAnalyzerRequest.scala <==
package zio.aws.accessanalyzer.model
import zio.aws.accessanalyzer.model.primitives.Name
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateAnalyzerRequest(
    analyzerName: Name,
    archiveRules: Optional[
      Iterable[zio.aws.accessanalyzer.model.InlineArchiveRule]
    ] = Optional.Absent,
    clientToken: Optional[String] = Optional.Absent,
    tags: Optional[Map[String, String]] = Optional.Absent,
    `type`: zio.aws.accessanalyzer.model.Type
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest = {
    import CreateAnalyzerRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest
      .builder()
      .analyzerName(Name.unwrap(analyzerName): java.lang.String)
      .optionallyWith(
        archiveRules.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.archiveRules)
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .`type`(`type`.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.accessanalyzer.model.CreateAnalyzerRequest.ReadOnly =
    zio.aws.accessanalyzer.model.CreateAnalyzerRequest.wrap(buildAwsValue())
}
object CreateAnalyzerRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.accessanalyzer.model.CreateAnalyzerRequest =
      zio.aws.accessanalyzer.model.CreateAnalyzerRequest(
        analyzerName,
        archiveRules.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        clientToken.map(value => value),
        tags.map(value => value),
        `type`
      )
    def analyzerName: Name
    def archiveRules: Optional[
      List[zio.aws.accessanalyzer.model.InlineArchiveRule.ReadOnly]
    ]
    def clientToken: Optional[String]
    def tags: Optional[Map[String, String]]
    def `type`: zio.aws.accessanalyzer.model.Type
    def getAnalyzerName: ZIO[Any, Nothing, Name] = ZIO.succeed(analyzerName)
    def getArchiveRules: ZIO[Any, AwsError, List[
      zio.aws.accessanalyzer.model.InlineArchiveRule.ReadOnly
    ]] = AwsError.unwrapOptionField("archiveRules", archiveRules)
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getTags: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("tags", tags)
    def getType: ZIO[Any, Nothing, zio.aws.accessanalyzer.model.Type] =
      ZIO.succeed(`type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest
  ) extends zio.aws.accessanalyzer.model.CreateAnalyzerRequest.ReadOnly {
    override val analyzerName: Name =
      zio.aws.accessanalyzer.model.primitives.Name(impl.analyzerName())
    override val archiveRules: Optional[
      List[zio.aws.accessanalyzer.model.InlineArchiveRule.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.archiveRules())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.accessanalyzer.model.InlineArchiveRule.wrap(item)
        }.toList
      )
    override val clientToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.clientToken())
      .map(value => value: String)
    override val tags: Optional[Map[String, String]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val `type`: zio.aws.accessanalyzer.model.Type =
      zio.aws.accessanalyzer.model.Type.wrap(impl.`type`())
  }
  def wrap(
      impl: software.amazon.awssdk.services.accessanalyzer.model.CreateAnalyzerRequest
  ): zio.aws.accessanalyzer.model.CreateAnalyzerRequest.ReadOnly = new Wrapper(
    impl
  )
}
